
#-------------------------------------------------------------------------
# Poll data map
#-------------------------------------------------------------------------

# Read data
polling_data <- readRDS("2_Cleaned_Data/polling_data.rds") %>% 
  mutate(label = case_when(label == "Flest skovbrande" ~ "Wildfires peak",
                           label == "Første skovbrand" ~ "First wildfire",
                           label == "Valgdag" ~ "Election day"))

# Plot vote share in polls over time 
plot2 <- polling_data %>%
  ggplot(aes(x = date, y = poll_share, color = Parti, group = Parti)) +
  geom_point() +
  geom_smooth(method = "loess") +
  theme_bw() +
  coord_cartesian(xlim = c(ymd("2018-01-01"), ymd("2018-12-31")), expand = FALSE) +
  scale_x_date(labels = date_format("%b"), breaks = date_breaks("months")) +
  scale_y_continuous("Estimated vote share") +
  scale_color_manual(labels = c("The Greens", "The Soc.Dems"), values = c("darkgreen", "red")) +
  geom_vline(xintercept = c(ymd("2018-05-22"), ymd("2018-07-24"), ymd("2018-09-09")), linetype = "dashed") +
  geom_text(aes(x = ymd("2018-05-22"), y = 0.18, label = "First wildfire"), hjust = 1.1, size = 5, color = "black") +
  geom_text(aes(x = ymd("2018-07-24"), y = 0.18, label = "Wildfires peak"), hjust = 1.05, size = 5, color = "black") +
  geom_text(aes(x = ymd("2018-09-09"), y = 0.18, label = "Election day"), hjust = -0.1, size = 5, color = "black") +
  theme(axis.line.y = element_blank(), axis.ticks.y = element_blank(), 
        axis.text = element_text(size = 14, color = "black"), axis.title.x = element_blank(),
        axis.title.y = element_text(size = 14, color = "black"),
        axis.ticks.x = element_blank(), plot.margin = unit(c(0.5, 0.5, 0.5, 0.55), "cm"), 
        panel.grid.major = element_blank(),
        panel.grid.minor = element_blank(), 
        legend.position = "top", legend.title = element_blank(),
        legend.text = element_text(size = 14, color = "black"),
        plot.caption = element_text(hjust=0.5, size=rel(1.2)),
        text = element_text(color = "black"))

# Save plot
pdf("4_Figures/ARTICLE_Polls_over_time.pdf", 12, 7.2)
plot2
dev.off()

#-------------------------------------------------------------------------
# Environment issue salience over time
#-------------------------------------------------------------------------

# Read data
env <- read.xlsx("1_Raw_Data/Dependent_variable/issue_env.xlsx") %>% 
  mutate(date = ymd(date)) %>% 
  filter(date > ymd("2014-12-30"))

data_ends <- env %>% 
  filter(date %in% c(ymd("2015-01-01"), ymd("2018-08-01")))

# Plot issue salience
plot3 <- env %>% 
  ggplot(aes(x = date, y = share)) +
  geom_point() +
  geom_line() +
  geom_rect(aes(xmin = as.Date("2018-03-01"), xmax = as.Date("2018-08-31"), ymin = -Inf, ymax = +Inf), fill = "red", alpha = 0.005) +
  theme_bw() +
  scale_x_date(labels = date_format("%b %Y"), breaks = c(ymd("2014-08-01"), ymd("2015-01-01"), ymd("2016-01-01"), 
                                                         ymd("2017-01-01"), ymd("2018-01-01"), ymd("2018-08-01"))) +
  scale_y_continuous(limits = c(0, 0.3)) +
  geom_vline(xintercept = ymd("2018-07-20"), linetype = "dashed") +
  theme(axis.line.y = element_blank(), axis.ticks.y = element_blank(), 
        axis.text = element_text(size = 14, colour = "black"), axis.title = element_blank(),
        plot.margin = unit(c(0.5, 0.5, 0.5, 0.55), "cm"), panel.grid.major = element_blank(),
        panel.grid.minor = element_blank(), legend.position = "top", legend.title = element_blank(),
        legend.text = element_text(size = 12)) +
  annotate(x = ymd("2018-07-20"), y = +Inf, label = "Wildfires peak", 
           vjust = 2, hjust = 1.07, size = 5, geom = "text")

# Save plot
pdf("4_Figures/ARTICLE_env_salience.pdf", 8, 6)
plot3
dev.off()

#-------------------------------------------------------------------------
# Forest fire map
#-------------------------------------------------------------------------

# Read data
fire_collected <- readRDS("2_Cleaned_Data/fire_data_collected.rds")
election <- readRDS("2_Cleaned_Data/election_data.rds")
controls <- readRDS("2_Cleaned_Data/controls.rds")

# Join independent, dependent and control variables
D <- left_join(election, fire_collected, by = c("Kommun", "year")) %>% 
  left_join(controls, by = c("Kommun", "year", "population"))

# Filter for year of wildfires
D_2018 <- D %>% 
  filter(year == 2018)

# Convert municipality codes to characters variable and NAs in damage indicator to zeroes
D_2018$knkod <- as.character(D_2018$knkod)
D_2018$burned_std <- ifelse(is.na(D_2018$burned_std), 0, D$burned_std)

# Filter dataframe for unique municipality names
D_map <- D_2018 %>% 
  distinct(knkod, .keep_all = TRUE)

# Join data with data from "swemaps"-package
map_sweden <- left_join(map_kn, D_map, by = "knkod")

# Adjust variable for the fill aesthetic
map_sweden$plot_experiment[which(map_sweden$knnamn %in% c("Stockholm", "Göteborg", "Malmö"))] <- "big city"

# Make label variable for geom_text_repel
map_sweden <- map_sweden %>% 
  mutate(label_name = if_else(knnamn %in% c("Stockholm", "Göteborg", "Malmö") & order %in% c(518, 2022, 2189), knnamn, ""))

# Plot
map_sweden %>% 
  ggplot(aes(ggplot_long, ggplot_lat, group = knkod, fill = plot_experiment)) +
  geom_polygon(color="lightgrey", size=.001) +
  geom_text_repel(aes(label = label_name),
                  position = position_identity(),
                  max.overlaps = 2000,
                  xlim = c(min(map_sweden$ggplot_long)-100, max(map_sweden$ggplot_long)+100),
                  show.legend = FALSE) +
  coord_equal() +
  scale_fill_manual(values = c("peachpuff", "red", "black"),
                    breaks = c("Control", "Treated"),
                    labels = c("Control group", "Treatment group"),
                    na.value = "black") +
  theme_classic() +
  theme(axis.title = element_blank(),
        axis.text = element_blank(),
        axis.ticks = element_blank(),
        axis.line = element_blank(),
        legend.title = element_blank(),
        legend.text = element_text(size = 18),
        legend.position = "top",
        plot.caption = element_text(hjust=0.5, size=rel(1.2)),
        plot.margin=grid::unit(c(0,0,0,0), "mm"))

ggsave("4_Figures/ARTICLE_Sweden_damage_map.pdf")

#-------------------------------------------------------------------------
# Descriptives on forest fires over time
#-------------------------------------------------------------------------

# Read raw fire data
fire_time <- readRDS("2_Cleaned_Data/raw_fire_data.rds")

# Summarise fire intensity for each year across municipalities
fire_sum <- fire_time %>% 
  left_join(D_map[, c("Kommun", "treat")], by = "Kommun") %>% 
  group_by(treat, year) %>% 
  summarise(burned_area = sum(burned_area),
            burned_area_per_hectar = sum(burned_area)/sum(land_area_hectar))

# Plot forest fires over years
plot1a <- ggplot(fire_sum, aes(x = year, y = burned_area/1000000, color = as.factor(treat))) +
  geom_line() +
  geom_point() +
  scale_x_continuous(breaks = unique(fire_sum$year)) +
  scale_y_continuous(labels = scales::label_comma()) +
  scale_colour_manual(values = c("0" = "blue", "1" = "red"),
                      labels = c("Control", "Treatment"),
                      name = "Treatment") +
  theme_bw() +
  theme(axis.text.x = element_text(angle = 45, hjust = 1)) +  # rotate x-axis labels for better readability
  theme(axis.line.y = element_blank(), axis.ticks.y = element_blank(), 
        axis.text = element_text(size = 14, color = "black"), axis.title.x = element_blank(),
        axis.title.y = element_blank(),
        panel.grid.minor = element_blank(), 
        legend.position = "top", legend.title = element_blank(),
        legend.text = element_text(size = 14, color = "black"),
        plot.caption = element_text(hjust=0.5, size=rel(1.2)),
        text = element_text(color = "black"))

# Save plot
pdf("4_Figures/ARTICLE_Fires_over_time.pdf", 10, 6)
plot1a
dev.off()

#-------------------------------------------------------------------------
# VALU Election data
#-------------------------------------------------------------------------

# Read VALU data from 2018 
valu_2018 <- read_sav("1_Raw_Data/Dependent_variable/2018_valu.sav")

# Find out who has issue ownership over environment issue in 2018. This is used to plot in latex table in the assignment
v18_parti <- valu_2018 %>% 
  select(f47) %>% 
  mutate(green = case_when(f47 == 7 ~ "Miljöpartiet",
                           f47 == 5 ~ "Socialdemokraterna",
                           f47 %in% c(1:4, 6, 81:83) ~ "Andre partier")) %>% 
  filter(!is.na(f47)) %>% 
  group_by(f47) %>% 
  tally() %>% 
  mutate(share = n / sum(n),
         year = "2018",
         get_label(valu_2018$f47))

# For Miljöpartiet
mp_v18 <- valu_2018 %>% 
  select(f1, f28, f47) %>% 
  mutate(salience = case_when(f28 %in% c(1:2) ~ 1,
                                 f28 %in% c(3:5) ~ 0),
          party_vote = ifelse(f1 == 7,1,0),
         party_ownership = ifelse(f47 == 7,1,0)) %>% 
  filter(!is.na(f28),
         !is.na(f47),
         !is.na(f1)) %>%
  mutate(label_salience = get_label(valu_2018$f28),
         label_vote = get_label(valu_2018$f1),
         label_ownership = get_label(valu_2018$f47))

# Logistical regressions
mp_test_salience <- glm(party_vote ~ salience, data = mp_v18)
mp_test_ownership <- glm(party_vote ~ party_ownership, data = mp_v18)
mp_test_interaction <- glm(party_vote ~ salience*party_ownership, data = mp_v18)

# Plot model in collective table
stargazer(mp_test_salience, mp_test_ownership, mp_test_interaction,
          dep.var.labels = "Propensity to vote for the Greens",
          covariate.labels = c("Salience", "Issue ownership", "Interaction"),
          type = "latex", digits = 2)

#-------------------------------------------------------------------------
# Plotting the burned_std variable
#-------------------------------------------------------------------------

# We only need the independent variable per municipality in 2018.
D_burned <- D %>% 
  filter(year==2018) %>% 
  select(Kommun, burned_std, burned_area) %>% 
  distinct() %>% 
  arrange(desc(burned_std))


# Use logged burned index to fit differences better
burned_area_desc_plot <- ggplot(D_burned, aes(reorder(Kommun, -burned_std), log(burned_std))) + geom_point() +
  geom_vline(xintercept = nrow(D_burned)*0.15, linetype = "dashed") + 
  ylab(expression(paste("Burned ", km^2, " per total municipal  ", km^2, ", logged"))) +
  xlab("Municipalities in treatment year") + 
  annotate(geom = "text", x = nrow(D_burned)*0.3, y = -5,
           label = "Treatment variable cut-off",
           size = 4.5) +
  theme(axis.text.x = element_blank(), 
    panel.grid.major = element_blank(),
    panel.grid.minor = element_blank(),
    panel.background = element_blank(),
    panel.border = element_rect(colour = "black", fill=NA),
    axis.ticks = element_blank(),
    text = element_text(size = 12, colour = "black"))

pdf("4_Figures/burned_area_desc_plot.pdf", 8, 6)
burned_area_desc_plot
dev.off()

#-------------------------------------------------------------------------
# Population descriptives
#-------------------------------------------------------------------------

# Read data
pop_area <- readRDS("2_Cleaned_Data/pop_area.rds")
inspect <- readRDS("2_Cleaned_Data/indicator_inspection.rds")

# Calculate mean population density for each municipality in the year 2018
pop_dens_18 <- pop_area %>% 
  filter(year == 2018 & !is.na(Kommun)) %>% 
  mutate(pop_dens = population / land_area_hectar,
         treat = ifelse(Kommun %in% inspect$Kommun, 1, 0)) %>% 
  group_by(treat) %>% 
  summarise(pop_dens_18 = median(pop_dens))

# Read population average age in 2018
pop_avg_age <- read.xlsx("1_Raw_Data/Controls/population_alder.xlsx")

# Join average age and treatment group 2018
pop_age <- pop_avg_age %>% 
  mutate(Kommun = str_trim(str_remove(Kommun, "[:digit:]{4} ")),
         treat = ifelse(Kommun %in% inspect$Kommun, 1, 0)) %>% 
  group_by(treat) %>% 
  summarise(pop_age = median(pop_avg_age))

# Read forest and total land area in 2015
forest_land_area <- read.xlsx("1_Raw_Data/Controls/forest_area_per_land.xlsx") # land use in Sweden, hectares by every fifth year, region and land use category

# Join with treatment group
forest_land_area_15 <- forest_land_area %>% 
  mutate(Kommun = str_trim(str_remove(Kommun, "[:digit:]{4} ")),
        treat = ifelse(Kommun %in% inspect$Kommun, 1, 0)) %>% 
  select(Kommun, total.forest.land, total.land.area, treat) %>% 
  group_by(treat) %>% 
  summarise(forest_land_area_15 = median(total.forest.land/total.land.area))

# Make table
medians_dat <- pop_dens_18 %>% 
  left_join(pop_age, by ="treat") %>% 
  left_join(forest_land_area_15, by="treat")

# Use numbers from medians_dat in a stargazer style table
medians_table <- data.frame(dens = c(12.6, 11.0), age = c(43.2, 45.0), forest = c(64.9, 80.4))
row.names(medians_table) <- c("Control group", "Treatment group")

tex_table <- stargazer(medians_table, summary=F, notes = "Population density is measured as number of citizens per land area in hectares")

cat(str_replace(str_replace(str_replace(tex_table, "dens", "Population density"), "age", "Population age"), "forest", "Share of forested land area \\(\\\\%\\)"))

