
#-------------------------------------------------------------------------
# Parallel trends
#-------------------------------------------------------------------------

# Read files containing election data, wildfire data and information on municipalities hit hardest by wildfires according to our indicator
election <- readRDS("2_Cleaned_Data/election_data.rds")
forest <- readRDS("2_Cleaned_Data/fire_data_collected.rds")
inspect <- readRDS("2_Cleaned_Data/indicator_inspection.rds")

#Calculate vote share
election <- election %>% 
  group_by(Kommun, year) %>% 
  mutate(vote_share = vote_share/sum(vote_share)) %>% 
  ungroup()

# Parallel trends just for Miljöpartiet
fire_data_mp <- election %>% 
  filter(Parti == "Miljöpartiet" & year %in% c(1998, 2002, 2006, 2010, 2014, 2018) & !is.na(vote_share)) %>%
  group_by(plot_experiment, year) %>%
  summarise(vote_share = mean(vote_share))

# Plot 
plot_mp <- fire_data_mp %>% 
  ggplot(aes(x = year, y = vote_share, color = plot_experiment, group = plot_experiment)) +
  geom_point(size = 1.5) +
  geom_line(linewidth = 0.7) +
  theme_bw() +
  scale_x_continuous("År", breaks = c(1998, 2002, 2006, 2010, 2014, 2018)) + 
  scale_y_continuous("Vote share") +
  scale_color_manual(values = c("black", "red"),
                     labels = c("Nontreated", "Treated")) +
  theme(axis.line.y = element_blank(), 
        axis.ticks.y = element_blank(), 
        axis.text.x = element_blank(), 
        axis.title.x = element_blank(),
        axis.title.y = element_text(size = 14, color = "black"),
        axis.ticks.x = element_blank(), 
        axis.text.y = element_text(size = 14, color = "black"),
        plot.margin = unit(c(0.5, 0.5, 0.5, 0.55), "cm"), 
        panel.grid.major = element_blank(),
        panel.grid.minor = element_blank(), 
        legend.position = "none", 
        legend.title = element_blank(),
        legend.text = element_text(size = 12)) +
  ggtitle("The Greens")

# Parallel trends just for Socialdemokraterna
fire_data_sd <- election %>% 
  filter(Parti == "Socialdemokraterna" & year %in% c(1998, 2002, 2006, 2010, 2014, 2018) & !is.na(vote_share)) %>%
  group_by(plot_experiment, year) %>%
  summarise(vote_share = mean(vote_share))

# Plot
plot_sd <- fire_data_sd %>% 
  ggplot(aes(x = year, y = vote_share, color = plot_experiment, group = plot_experiment)) +
  geom_point(size = 1.5) +
  geom_line(linewidth = 0.7) +
  theme_bw() +
  scale_x_continuous("År", breaks = c(1998, 2002, 2006, 2010, 2014, 2018)) + 
  scale_y_continuous("Vote share") +
  scale_color_manual(values = c("black", "red"),
                     labels = c("Nontreated", "Treated")) +
  theme(axis.line.y = element_blank(), axis.ticks.y = element_blank(), 
        axis.text.x = element_text(color = "black", size = 14),
        axis.title.x = element_blank(),
        axis.title.y = element_text(size = 14, color = "black"),
        axis.ticks.x = element_blank(), 
        axis.text.y = element_text(size = 14, color = "black"),
        plot.margin = unit(c(0.5, 0.5, 0.5, 0.55), "cm"), 
        panel.grid.major = element_blank(),
        panel.grid.minor = element_blank(), 
        legend.position = "bottom",
        legend.title = element_blank(),
        legend.text = element_text(size = 14, color = "black"),
        plot.caption = element_text(hjust=0.5, size=rel(1.2))) +
  ggtitle("The SSDP")

### Printing for article
pdf("4_Figures/ARTICLE_parallel_trends_parties.pdf", height = 8, width = 6)
grid.arrange(arrangeGrob(plot_mp, plot_sd, nrow = 2, ncol = 1))
dev.off()