#-------------------------------------------------------------------------------------------
# Exclude potentially pre-treated municipalities in the control group
#-------------------------------------------------------------------------------------------

# Read data
D_mp <- readRDS("2_Cleaned_Data/D_mp.rds")
D_sd <- readRDS("2_Cleaned_Data/D_sd.rds")

# Run analyses with subset excluding municipalities from the Västmanland fires

### The Greens

# Table C.8, column 1
greens_pre1 <- felm(vote_share ~ experiment + year:treat 
             | factor(Kommun) + factor(year)  
             |0                            
             |Kommun,                
             data = D_mp %>% filter(!Kommun %in% c("Surahammar", "Sala", "Fagersta", "Norberg")))                   
summary(greens_pre1)

# Table C.8, column 2
greens_pre2 <- felm(vote_share ~ experiment + year:treat +
               budget +
               unemployment
             | factor(Kommun) + factor(year) 
             |0                            
             |Kommun,                
             data = D_mp %>% filter(!Kommun %in% c("Surahammar", "Sala", "Fagersta", "Norberg")))                    
summary(greens_pre2)

# Table C.8, column 3
greens_pre3 <- felm(vote_share ~ experiment + year:treat +
               budget +
               unemployment +
               immigration
             | factor(Kommun) + factor(year) 
             |0                            
             |Kommun,                
             data = D_mp %>% filter(!Kommun %in% c("Surahammar", "Sala", "Fagersta", "Norberg")))                   
summary(greens_pre3)

# Table C.8, column 4
greens_pre4 <- felm(vote_share ~ experiment + year:treat +
               budget + 
               unemployment +
               immigration +
               crime
             | factor(Kommun) + factor(year) 
             |0                            
             |Kommun,                
             data = D_mp %>% filter(!Kommun %in% c("Surahammar", "Sala", "Fagersta", "Norberg")))                   
summary(greens_pre3)

# Table for LaTeX
stargazer(greens_pre1, greens_pre2, greens_pre3, greens_pre4,
          dep.var.labels = "The Greens vote share",
          covariate.labels = c("Wildfires 2018", "Budget", "Unemployment", "Immigration",
                               "Reported crime rate"),
          add.lines = list(c("FE for municipality", "\\checkmark", "\\checkmark", "\\checkmark", "\\checkmark"),
                           c("FE for year", "\\checkmark", "\\checkmark", "\\checkmark", "\\checkmark"),
                           c("Linear trend control", "\\checkmark", "\\checkmark", "\\checkmark", "\\checkmark")),
          type = "latex", digits = 2,
          omit = c("year", "treat"),
          omit.stat = c("rsq", "adj.rsq"),
          notes = "Clustered (Municipality) standard-errors in parentheses")


### SSDP

# Table C.9, column 1
ssdp_pre1 <- felm(vote_share ~ experiment + year:treat 
             | factor(Kommun) + factor(year)  
             |0                            
             |Kommun,                
             data = D_sd %>% filter(!Kommun %in% c("Surahammar", "Sala", "Fagersta", "Norberg")))                    
summary(ssdp_pre1)

# Table C.9, column 2
ssdp_pre2 <- felm(vote_share ~ experiment + year:treat +
               budget +
               unemployment
             | factor(Kommun) + factor(year) 
             |0                            
             |Kommun,                
             data = D_sd %>% filter(!Kommun %in% c("Surahammar", "Sala", "Fagersta", "Norberg")))                    
summary(ssdp_pre2)

# Table C.9, column 3
ssdp_pre3 <- felm(vote_share ~ experiment + year:treat +
               budget +
               unemployment +
               immigration
             | factor(Kommun) + factor(year) 
             |0                            
             |Kommun,                
             data = D_sd %>% filter(!Kommun %in% c("Surahammar", "Sala", "Fagersta", "Norberg")))                   
summary(ssdp_pre3)

# Table C.9, column 4
ssdp_pre4 <- felm(vote_share ~ experiment + year:treat +
               budget + 
               unemployment +
               immigration +
               crime
             | factor(Kommun) + factor(year) 
             |0                            
             |Kommun,                
             data = D_sd %>% filter(!Kommun %in% c("Surahammar", "Sala", "Fagersta", "Norberg")))                    
summary(ssdp_pre4)

# Table for LaTeX
stargazer(ssdp_pre1, ssdp_pre2, ssdp_pre3, ssdp_pre4,
          dep.var.labels = "SSDP vote share",
          covariate.labels = c("Wildfires 2018", "Budget", "Unemployment", "Immigration",
                               "Reported crime rate"),
          add.lines = list(c("FE for municipality", "\\checkmark", "\\checkmark", "\\checkmark", "\\checkmark"),
                           c("FE for year", "\\checkmark", "\\checkmark", "\\checkmark", "\\checkmark"),
                           c("Linear trend control", "\\checkmark", "\\checkmark", "\\checkmark", "\\checkmark")),
          type = "latex", digits = 2,
          omit = c("year", "treat"),
          omit.stat = c("rsq", "adj.rsq"),
          notes = "Clustered (Municipality) standard-errors in parentheses")

# Read pre-treated municipalities
treated_2014 <- readRDS("2_Cleaned_Data/treated_2014.rds")

# add municipality-year variable to filter by
D_mp <- D_mp %>% 
  mutate(mun_year = paste0(Kommun, "_", year))

D_sd <- D_sd %>% 
  mutate(mun_year = paste0(Kommun, "_", year))

# Run analyses with subset

### The Greens
# Table C.10, column 1
greens_pre5 <- felm(vote_share ~ experiment + year:treat 
                 | factor(Kommun) + factor(year)  
                 |0                            
                 |Kommun,                
                 data = D_mp %>% filter(!mun_year %in% treated_2014))                   
summary(greens_pre5)

# Table C.10, column 2
greens_pre6 <- felm(vote_share ~ experiment + year:treat +
                     budget +
                     unemployment
                   | factor(Kommun) + factor(year) 
                   |0                            
                   |Kommun,                
                   data = D_mp %>% filter(!mun_year %in% treated_2014))                   
summary(greens_pre6)

# Table C.10, column 3
greens_pre7 <- felm(vote_share ~ experiment + year:treat +
                     budget +
                     unemployment +
                     immigration
                   | factor(Kommun) + factor(year) 
                   |0                            
                   |Kommun,                
                   data = D_mp %>% filter(!mun_year %in% treated_2014))                   
summary(greens_pre7)

# Table C.10, column 4
greens_pre8 <- felm(vote_share ~ experiment + year:treat +
                     budget + 
                     unemployment +
                     immigration +
                     crime
                   | factor(Kommun) + factor(year) 
                   |0                            
                   |Kommun,                
                   data = D_mp %>% filter(!mun_year %in% treated_2014))                   
summary(greens_pre5)

# Table for LaTeX
stargazer(greens_pre5, greens_pre6, greens_pre7, greens_pre8,
          dep.var.labels = "The Greens vote share",
          covariate.labels = c("Wildfires 2018", "Budget", "Unemployment", "Immigration",
                               "Reported crime rate"),
          add.lines = list(c("FE for municipality", "\\checkmark", "\\checkmark", "\\checkmark", "\\checkmark"),
                           c("FE for year", "\\checkmark", "\\checkmark", "\\checkmark", "\\checkmark"),
                           c("Linear trend control", "\\checkmark", "\\checkmark", "\\checkmark", "\\checkmark")),
          type = "latex", digits = 2,
          omit = c("year", "treat"),
          omit.stat = c("rsq", "adj.rsq"),
          notes = "Clustered (Municipality) standard-errors in parentheses")


### SSDP

# Table C.11, column 1
ssdp_pre5 <- felm(vote_share ~ experiment + year:treat 
                 | factor(Kommun) + factor(year)  
                 |0                            
                 |Kommun,                
                 data = D_sd %>% filter(!mun_year %in% treated_2014))                   
summary(ssdp_pre5)

# Table C.11, column 2
ssdp_pre6 <- felm(vote_share ~ experiment + year:treat +
                     budget +
                     unemployment
                   | factor(Kommun) + factor(year) 
                   |0                            
                   |Kommun,                
                   data = D_sd %>% filter(!mun_year %in% treated_2014))                   
summary(ssdp_pre6)

# Table C.11, column 3
ssdp_pre7 <- felm(vote_share ~ experiment + year:treat +
                     budget +
                     unemployment +
                     immigration
                   | factor(Kommun) + factor(year) 
                   |0                            
                   |Kommun,                
                   data = D_sd %>% filter(!mun_year %in% treated_2014))                   
summary(ssdp_pre7)

# Table C.11, column 4
ssdp_pre8 <- felm(vote_share ~ experiment + year:treat +
                     budget + 
                     unemployment +
                     immigration +
                     crime
                   | factor(Kommun) + factor(year) 
                   |0                            
                   |Kommun,                
                   data = D_sd %>% filter(!mun_year %in% treated_2014))                   
summary(ssdp_pre8)

# Table for LaTeX
stargazer(ssdp_pre5, ssdp_pre6, ssdp_pre7, ssdp_pre8,
          dep.var.labels = "SSDP vote share",
          covariate.labels = c("Wildfires 2018", "Budget", "Unemployment", "Immigration",
                               "Reported crime rate"),
          add.lines = list(c("FE for municipality", "\\checkmark", "\\checkmark", "\\checkmark", "\\checkmark"),
                           c("FE for year", "\\checkmark", "\\checkmark", "\\checkmark", "\\checkmark"),
                           c("Linear trend control", "\\checkmark", "\\checkmark", "\\checkmark", "\\checkmark")),
          type = "latex", digits = 2,
          omit = c("year", "treat"),
          omit.stat = c("rsq", "adj.rsq"),
          notes = "Clustered (Municipality) standard-errors in parentheses")

#-------------------------------------------------------------------------------------------
# Event study models
#-------------------------------------------------------------------------------------------

### The Greens

# Prepare factor for year dummies (leave out 2014)
D_mp$yearfactor <- ifelse(D_mp$year!=2014, D_mp$year, 0) #zero for year 2014
D_mp$yearfactor <- factor(D_mp$yearfactor, levels=c(0, 1998, 2002, 2006, 2010, 2018))

# Prepare factor for year:treated dummies (version with no trend: leave out 2014)
D_mp$yeartreated <- ifelse(D_mp$treat==1, D_mp$year, 0) #zero for all control units
D_mp$yeartreatedfactor <- ifelse(D_mp$yeartreated != 2014, D_mp$yeartreated, 0) #zero for year 2014
D_mp$yeartreatedfactor <- factor(D_mp$yeartreatedfactor, levels=c(0, 1998, 2002, 2006, 2010, 2018))

# Run model with no controls/trend
mp_eventstudy_nocontrol <- feols(vote_share ~ yearfactor + yeartreatedfactor | Kommun,
                                 cluster = ~ Kommun, data = D_mp)

# Update factor for year:treated dummies (versions with trend: leave out 1998 and 2014)
D_mp$yeartreatedfactor <- ifelse(!(D_mp$yeartreated %in% c(2014, 1998)), D_mp$yeartreated, 0) #zero for years 1998 and 2014
D_mp$yeartreatedfactor <- factor(D_mp$yeartreatedfactor, levels=c(0, 2002, 2006, 2010, 2018))

# Run models with trend and controls
mp_eventstudy_trend <- feols(vote_share ~ yearfactor + yeartreatedfactor + treat:year | Kommun,
                             cluster = ~ Kommun, data = D_mp)
mp_eventstudy_trend_controls <- feols(vote_share ~ yearfactor + yeartreatedfactor + treat:year +
                                        budget + unemployment + immigration + crime| Kommun,
                                      cluster = ~ Kommun, data = D_mp)

# Get year-treated group dummy coefficients for plotting
event_list <- list(mp_eventstudy_nocontrol, mp_eventstudy_trend, mp_eventstudy_trend_controls)
event_names <- c("No trend or controls", "Treated linear trend", "Trend + controls")
coef_list <- list()
election_years <- c(2002, 2006, 2010, 2018, 2014)
coefnames <- paste0("yeartreatedfactor", c(2002, 2006, 2010, 2018))
for(i in 1:3){
  coefs <- as.data.frame(event_list[[i]]$coeftable[coefnames,])
  CIs <- confint(event_list[[i]], coefnames)
  colnames(CIs) <- c("CI2.5","CI97.5")
  coefs <- cbind(coefs, CIs)
  coefs <- rbind(coefs, c(0,0,0,0))
  coefs$year <- election_years
  coefs$specification <- event_names[i]
  rownames(coefs) <- NULL
  coef_list[[i]] <- coefs
}
mp_event_coefs <- do.call(rbind, coef_list)

# Plot coefficients
mp_event <- ggplot(mp_event_coefs, aes(x=year, y=Estimate)) +
  geom_point() + facet_wrap(~specification) +
  scale_x_continuous("Year", breaks=election_years) +
  theme_bw() +
  geom_errorbar(aes(ymin=CI2.5, ymax=CI97.5, width=0.2)) +
  geom_hline(yintercept=0) +
  geom_vline(xintercept=2014, linetype="dotted") +
  ggtitle("The Greens") +
  theme(strip.background = element_rect(fill = "white"),
        strip.text = element_text(size = rel(1.2)),
        axis.title = element_text(size = 16),
        axis.text = element_text(size = 12, color = "black"),
        axis.ticks.length = unit(.25, "cm"),
        plot.caption = element_text(hjust=0.5, size=rel(1.5)))


### SSDP

# Prepare factor for year dummies (leave out 2014)
D_sd$yearfactor <- ifelse(D_sd$year!=2014, D_sd$year, 0) #zero for year 2014
D_sd$yearfactor <- factor(D_sd$yearfactor, levels=c(0, 1998, 2002, 2006, 2010, 2018))

# Prepare factor for year:treated dummies (version with no trend: leave out 2014)
D_sd$yeartreated <- ifelse(D_sd$treat==1, D_sd$year, 0) #zero for all control units
D_sd$yeartreatedfactor <- ifelse(D_sd$yeartreated != 2014, D_sd$yeartreated, 0) #zero for year 2014
D_sd$yeartreatedfactor <- factor(D_sd$yeartreatedfactor, levels=c(0, 1998, 2002, 2006, 2010, 2018))

# Run model with no controls/trend
sd_eventstudy_nocontrol <- feols(vote_share ~ yearfactor + yeartreatedfactor | Kommun,
                                 cluster = ~ Kommun, data = D_sd)

# Update factor for year:treated dummies (versions with trend: leave out 1998 and 2014)
D_sd$yeartreatedfactor <- ifelse(!(D_sd$yeartreated %in% c(2014, 1998)), D_sd$yeartreated, 0) #zero for years 1998 and 2014
D_sd$yeartreatedfactor <- factor(D_sd$yeartreatedfactor, levels=c(0, 2002, 2006, 2010, 2018))

# Run models with trend and controls
sd_eventstudy_trend <- feols(vote_share ~ yearfactor + yeartreatedfactor + treat:year | Kommun,
                             cluster = ~ Kommun, data = D_sd)
sd_eventstudy_trend_controls <- feols(vote_share ~ yearfactor + yeartreatedfactor + treat:year +
                                        budget + unemployment + immigration + crime| Kommun,
                                      cluster = ~ Kommun, data = D_sd)

# Get year-treated group dummy coefficients for plotting
event_list <- list(sd_eventstudy_nocontrol, sd_eventstudy_trend, sd_eventstudy_trend_controls)
coef_list <- list()
for(i in 1:3){
  coefs <- as.data.frame(event_list[[i]]$coeftable[coefnames,])
  CIs <- confint(event_list[[i]], coefnames)
  colnames(CIs) <- c("CI2.5","CI97.5")
  coefs <- cbind(coefs, CIs)
  coefs <- rbind(coefs, c(0,0,0,0))
  coefs$year <- election_years
  coefs$specification <- event_names[i]
  rownames(coefs) <- NULL
  coef_list[[i]] <- coefs
}
sd_event_coefs <- do.call(rbind, coef_list)

# Plot coefficients
ssdp_event <- ggplot(sd_event_coefs, aes(x=year, y=Estimate)) +
  geom_point() + facet_wrap(~specification) +
  scale_x_continuous("Year", breaks=election_years) +
  theme_bw() +
  geom_errorbar(aes(ymin=CI2.5, ymax=CI97.5, width=0.2)) +
  geom_hline(yintercept=0) +
  geom_vline(xintercept=2014, linetype="dotted") +
  ggtitle("The SSDP") +
  theme(strip.background = element_rect(fill = "white"),
        strip.text = element_text(size = rel(1.2)),
        axis.title = element_text(size = 16),
        axis.text = element_text(size = 12, color = "black"),
        axis.ticks.length = unit(.25, "cm"),
        plot.caption = element_text(hjust=0.5, size=rel(1.5)))

pdf("4_Figures/event_study_plots.pdf", height = 8, width = 12, unit)
grid.arrange(arrangeGrob(mp_event, ssdp_event, nrow = 2, ncol = 1))
dev.off()

#-------------------------------------------------------------------
# Random permutations placebo test
#-------------------------------------------------------------------

# Read data
D_mp <- readRDS("2_Cleaned_Data/D_mp.rds")
D_sd <- readRDS("2_Cleaned_Data/D_sd.rds")
greens_DiD4 <- readRDS("2_Cleaned_Data/greens_DiD4.rds")
ssdp_DiD4 <- readRDS("2_Cleaned_Data/ssdp_DiD4.rds")
election <- readRDS("2_Cleaned_Data/election_data.rds")

# Get data and omit missing values
used_mp <- na.omit(select(D_mp, vote_share, experiment, Kommun, year, crime, unemployment, budget, immigration, treat))
used_sd <- na.omit(select(D_sd, vote_share, experiment, Kommun, year, crime, unemployment, budget, immigration, treat))

# Create a numeric indicator for each municipality
used_mp$Kommun_id <- used_mp %>%
  group_by(Kommun) %>%
  group_indices()

used_sd$Kommun_id <- used_sd %>%
  group_by(Kommun) %>%
  group_indices()

# Define the structure
CTRL_mp <- how(blocks = factor(used_mp$Kommun_id))
CTRL_sd <- how(blocks = factor(used_sd$Kommun_id))

# Do 1000 parallel permutations
set.seed(44) # set seed for reproducibility
perm_sd <- shuffleSet(used_mp$experiment,    # shuffle the treatment variable
                   nset = 1000,    # number of permutations
                   control = CTRL_mp) # definition of structure

perm_mp <- shuffleSet(used_sd$experiment,   
                      nset = 1000,  
                      control = CTRL_sd)

cl <- makeCluster(detectCores()-1) # create a cluster with all but 1 core
registerDoParallel(cl) # register the cluster

# Create a loop that can run in parallel on different processors
res_mp <- foreach(i = 1:nrow(perm_mp), # loop all rows in "perm"
                  .combine = "rbind", 
                  .packages = "lfe") %dopar% {
                    
                    # Use alternative indexations in "perm" to create new random treatment variables
                    crnt_perm <- perm_mp[i,]
                    used_mp$this_treat <- used_mp$experiment[crnt_perm]
                    
                    # Use the new variables in our generalized DiD
                    this_mod <-felm(vote_share ~ this_treat + year:treat +
                                      budget + 
                                      unemployment +
                                      immigration +
                                      crime
                                    | factor(Kommun) + factor(year) 
                                    |0                            
                                    |Kommun, 
                                    data = used_mp)
                    
                    # Return the coefficients
                    coef(this_mod)[1]
                  }
res_sd <- foreach(i = 1:nrow(perm_sd),          
               .combine = "rbind", 
               .packages = "lfe") %dopar% {
                 
                 # Use alternative indexations in "perm" to create new random treatment variables
                 crnt_perm <- perm_sd[i,]
                 used_sd$this_treat <- used_sd$experiment[crnt_perm]
                 
                 # Use the new variables in our generalized DiD
                 this_mod <-felm(vote_share ~ this_treat + year:treat +
                                   budget + 
                                   unemployment +
                                   immigration +
                                   crime
                                 | factor(Kommun) + factor(year) 
                                 |0                            
                                 |Kommun, 
                                 data = used_sd)
                 
                 # Return the coefficients
                 coef(this_mod)[1]
               }

stopCluster(cl) # shut down the cluster

res_mp <- as.data.frame(res_mp) # put all the coefficients into a dataframe
res_sd <- as.data.frame(res_sd)

# Create histograms of all the randomly generated estimates and mark the actual estimate
p1 <- ggplot(res_mp, aes(x = this_treat)) +
  geom_histogram(fill = "grey", colour = "white", bins = 30) +
  geom_vline(xintercept = coef(greens_DiD4)[1], lty = 3) +
  theme_classic() + 
  labs(x = "",
       y = "Number of estimates") +
  annotate(geom = "text", x = coef(greens_DiD4)[1]-0.2, y = 125,
           label = "Actual generalised\nDiD estimate",
           size = 4.5) +
  scale_x_continuous(limits = c(-coef(greens_DiD4)[1], coef(greens_DiD4)[1])) + 
  theme(axis.title = element_text(size = 16),
        axis.text = element_text(size = 12, color = "black"),
        axis.ticks.x = element_blank()) +
  ggtitle("The Greens")

p2 <- ggplot(res_sd, aes(x = this_treat)) +
  geom_histogram(fill = "grey", colour = "white") +
  geom_vline(xintercept = coef(ssdp_DiD4)[1], lty = 3) +
  theme_classic() + 
  labs(x = "Permutated estimates",
       y = "Number of estimates") +
  annotate(geom = "text", x = coef(ssdp_DiD4)[1]+.9, y = 200,
           label = "Actual generalised\nDiD estimate",
           size = 4.5) +
  scale_x_continuous(limits = c(coef(ssdp_DiD4)[1], -coef(ssdp_DiD4)[1])) + 
  theme(axis.title = element_text(size = 16),
        axis.text = element_text(size = 12, color = "black"),
        axis.ticks.x = element_blank(),
        plot.caption = element_text(hjust=0.5, size=rel(1.2))) +
  ggtitle("The SSDP") 

# Print for article
pdf("4_Figures/ARTICLE_robust.pdf", height = 10, width = 10)
grid.arrange(arrangeGrob(p1, p2, nrow = 2, ncol = 1))
dev.off()

#-------------------------------------------------------------------
# Random permutations placebo test excluding the treated municipalities
#-------------------------------------------------------------------

# Exclude treated municipalities, then randomly generate a new treatment variable
# For the Greens
used_mp_ex <- used_mp %>% 
  filter(experiment==0)

used_mp_ex$experiment[sample(nrow(used_mp_ex), 44)] <- 1 # assign 44 municipalities as treated at random

# For SSDP
used_sd_ex <- used_sd %>% 
  filter(experiment==0)

used_sd_ex$experiment[sample(nrow(used_sd_ex), 44)] <- 1

# Define the structure
CTRL_mp_ex <- how(blocks = factor(used_mp_ex$Kommun_id))
CTRL_sd_ex <- how(blocks = factor(used_sd_ex$Kommun_id))

# Do 1000 parallel permutations
set.seed(44) # set seed for reproducibility
perm_sd_ex <- shuffleSet(used_mp_ex$experiment,    # shuffle the treatment variable
                      nset = 1000,    # number of permutations
                      control = CTRL_mp_ex) # definition of structure

perm_mp_ex <- shuffleSet(used_sd_ex$experiment,   
                      nset = 1000,  
                      control = CTRL_sd_ex)

cl <- makeCluster(detectCores()-1) # create a cluster with all but 1 core
registerDoParallel(cl) # register the cluster

# Create a loop that can run in parallel on different processors
res_mp_ex <- foreach(i = 1:nrow(perm_mp_ex), # loop all rows in "perm"
                  .combine = "rbind", 
                  .packages = "lfe") %dopar% {
                    
                    # Use alternative indexations in "perm" to create new random treatment variables
                    crnt_perm <- perm_mp_ex[i,]
                    used_mp_ex$this_treat <- used_mp_ex$experiment[crnt_perm]
                    
                    # Use the new variables in our generalized DiD
                    this_mod <-felm(vote_share ~ this_treat + year:treat +
                                      budget + 
                                      unemployment +
                                      immigration +
                                      crime
                                    | factor(Kommun) + factor(year) 
                                    |0                            
                                    |Kommun, 
                                    data = used_mp_ex)
                    
                    # Return the coefficients
                    coef(this_mod)[1]
                  }
res_sd_ex <- foreach(i = 1:nrow(perm_sd_ex),          
                  .combine = "rbind", 
                  .packages = "lfe") %dopar% {
                    
                    # Use alternative indexations in "perm" to create new random treatment variables
                    crnt_perm <- perm_sd_ex[i,]
                    used_sd_ex$this_treat <- used_sd_ex$experiment[crnt_perm]
                    
                    # Use the new variables in our generalized DiD
                    this_mod <-felm(vote_share ~ this_treat + year:treat +
                                      budget + 
                                      unemployment +
                                      immigration +
                                      crime
                                    | factor(Kommun) + factor(year) 
                                    |0                            
                                    |Kommun, 
                                    data = used_sd_ex)
                    
                    # Return the coefficients
                    coef(this_mod)[1]
                  }

stopCluster(cl) # shut down the cluster

res_mp_ex <- as.data.frame(res_mp_ex) # put all the coefficients into a dataframe
res_sd_ex <- as.data.frame(res_sd_ex)

# Create histogram of all the randomly generated estimates and mark the actual estimate
p3 <- ggplot(res_mp_ex, aes(x = this_treat)) +
  geom_histogram(fill = "grey", colour = "white", bins = 30) +
  geom_vline(xintercept = coef(greens_DiD4)[1], lty = 3) +
  theme_classic() + 
  labs(x = "",
       y = "Number of estimates") +
  annotate(geom = "text", x = coef(greens_DiD4)[1]-0.2, y = 125,
           label = "Actual generalised\nDiD estimate",
           size = 4.5) +
  scale_x_continuous(limits = c(-coef(greens_DiD4)[1], coef(greens_DiD4)[1])) + 
  theme(axis.title = element_text(size = 16),
        axis.text = element_text(size = 12, color = "black"),
        axis.ticks.x = element_blank()) +
  ggtitle("The Greens")

p4 <- ggplot(res_sd_ex, aes(x = this_treat)) +
  geom_histogram(fill = "grey", colour = "white") +
  geom_vline(xintercept = coef(ssdp_DiD4)[1], lty = 3) +
  theme_classic() + 
  labs(x = "Permutated estimates",
       y = "Number of estimates") +
  annotate(geom = "text", x = coef(ssdp_DiD4)[1]+.9, y = 200,
           label = "Actual generalised\nDiD estimate",
           size = 4.5) +
  scale_x_continuous(limits = c(coef(ssdp_DiD4)[1], -coef(ssdp_DiD4)[1])) + 
  theme(axis.title = element_text(size = 16),
        axis.text = element_text(size = 12, color = "black"),
        axis.ticks.x = element_blank(),
        plot.caption = element_text(hjust=0.5, size=rel(1.2))) +
  ggtitle("The SSDP")

# Print for article
pdf("4_Figures/ARTICLE_robust_ex_treat.pdf", height = 10, width = 10)
grid.arrange(arrangeGrob(p3, p4, nrow = 2, ncol = 1))
dev.off()

#-------------------------------------------------------------------------------------------
# Pretend the fires occured in 2014
#-------------------------------------------------------------------------------------------

# Filter for municipalities hit by wildfires
list_experiment <- D_mp %>% 
  filter(experiment == 1)

# Filter out 2018 and use the treatment variable from the simple DiD to set 2014 as 1 and 2010 as 0
D_mp_r <- D_mp %>%
  mutate(experiment = if_else(Kommun %in% c(list_experiment$Kommun) & year == 2014, 1, 0)) %>% 
  filter(year != 2018) %>%
  mutate(exp_robust = replace_na(experiment, 0))

# Table 5, column1
greens_DiD_r1 <- felm(vote_share ~ exp_robust + year:treat
              | factor(Kommun) + factor(year) 
              |0                            
              |Kommun,                
              data = D_mp_r)                    
summary(greens_DiD_r1)

# Table 5, column 2
greens_DiD_r2 <- felm(vote_share ~ exp_robust + year:treat +
                      budget +
                      unemployment
                | factor(Kommun) + factor(year)
                |0                            
                |Kommun,                
                data = D_mp_r)                  
summary(greens_DiD_r2)

# Table 5, column 3
greens_DiD_r3 <- felm(vote_share ~ exp_robust + year:treat +
                      budget +
                      unemployment +
                      immigration
                | factor(Kommun) + factor(year) 
                |0                         
                |Kommun,               
                data = D_mp_r)                  
summary(greens_DiD_r3)

# Table 5, column 4
greens_DiD_r4 <- felm(vote_share ~ exp_robust + year:treat +
                  budget + 
                  unemployment +
                  immigration +
                  crime
                | factor(Kommun) + factor(year) 
                |0                            
                |Kommun,                
                data = D_mp_r)                   
summary(greens_DiD_r4)

# Table for LaTeX
stargazer(greens_DiD_r1, greens_DiD_r2, greens_DiD_r3, greens_DiD_r4,
          dep.var.labels = "The Greens vote share",
          covariate.labels = c("Wildfires 2018", "Budget", "Unemployment", "Immigration",
                               "Reported crime rate"),
          add.lines = list(c("FE for municipality", "\\checkmark", "\\checkmark", "\\checkmark", "\\checkmark"),
                           c("FE for year", "\\checkmark", "\\checkmark", "\\checkmark", "\\checkmark"),
                           c("Linear trend control", "\\checkmark", "\\checkmark", "\\checkmark", "\\checkmark")),
          type = "latex", digits = 2,
          omit = c("year", "treat"),
          omit.stat = c("rsq", "adj.rsq"),
          notes = "Clustered (Municipality) standard-errors in parentheses")

#-------------------------------------------------------------------------------------------
# Test the effect of increasing damage caused by wildfires (for appendix)
#-------------------------------------------------------------------------------------------

### The Greens

### 85th percentile
# Alter indicator
DF85_mp <- D_mp %>%
  mutate(experiment = ifelse(burned_std > quantile(burned_std, 0.85, na.rm = TRUE) & year == 2018, 1, 0))

# Table E.14, column 1
greens_85 <- felm(vote_share ~ experiment + year:treat +
                      budget + 
                      unemployment +
                      immigration +
                      crime
                    | factor(Kommun) + factor(year)
                    |0                          
                    |Kommun,                
                    data = DF85_mp)                   

### 90th percentile
# Alter indicator
DF90_mp <- D_mp %>%
  mutate(experiment = ifelse(burned_std > quantile(burned_std, 0.90, na.rm = TRUE) & year == 2018, 1, 0))

# Table E.14, column 2
greens_90 <- felm(vote_share ~ experiment + year:treat +
                    budget + 
                    unemployment +
                    immigration +
                    crime
                    | factor(Kommun) + factor(year) 
                    |0                          
                    |Kommun,                
                    data = DF90_mp)                    


### 95th percentile
# Alter indicator
DF95_mp <- D_mp %>%
  mutate(experiment = ifelse(burned_std > quantile(burned_std, 0.95, na.rm = TRUE) & year == 2018, 1, 0))

# Table E.14, column 3
greens_95 <- felm(vote_share ~ experiment + year:treat +
                    budget + 
                    unemployment +
                    immigration +
                    crime
                    | factor(Kommun) + factor(year) 
                    |0       
                    |Kommun,                
                    data = DF95_mp)                  

# Table for LaTeX
stargazer(greens_85, greens_90, greens_95,
          dep.var.labels = "The Greens vote share",
          column.labels = c("> 85 pct.", "> 90 pct.", "> 95 pct."),
          covariate.labels = c("Wildfires 2018", "Budget", "Unemployment", "Immigration",
                               "Reported crime rate"),
          add.lines = list(c("FE for municipality", "\\checkmark", "\\checkmark", "\\checkmark", "\\checkmark"),
                           c("FE for year", "\\checkmark", "\\checkmark", "\\checkmark", "\\checkmark"),
                           c("Linear trend control", "\\checkmark", "\\checkmark", "\\checkmark", "\\checkmark")),
          type = "latex", digits = 2,
          omit = c("year", "treat"),
          omit.stat = c("rsq", "adj.rsq"),
          notes = "Clustered (Municipality) standard-errors in parentheses")


### SSDP

### 85th percentile
# Alter indicator
DF85_sd <- D_sd %>%
  mutate(experiment = ifelse(burned_std > quantile(burned_std, 0.85, na.rm = TRUE) & year == 2018, 1, 0))

# Fixed effects with controls
ssdp_85 <- felm(vote_share ~ experiment + year:treat +
                  budget + 
                  unemployment +
                  immigration +
                  crime
                    | factor(Kommun) + factor(year) 
                    |0                            
                    |Kommun,                
                    data = DF85_sd)                    

### 90th percentile
# Alter indicator
DF90_sd <- D_sd %>%
  mutate(experiment = ifelse(burned_std > quantile(burned_std, 0.90, na.rm = TRUE) & year == 2018, 1, 0))

# Fixed effects with controls
ssdp_90 <- felm(vote_share ~ experiment + year:treat +
                  budget + 
                  unemployment +
                  immigration +
                  crime
                    | factor(Kommun) + factor(year)
                    |0                          
                    |Kommun,              
                    data = DF90_sd)               


### 95th percentile
# Alter indicator
DF95_sd <- D_sd %>%
  mutate(experiment = ifelse(burned_std > quantile(burned_std, 0.95, na.rm = TRUE) & year == 2018, 1, 0))

# Fixed effects with controls
ssdp_95 <- felm(vote_share ~ experiment + year:treat +
                  budget + 
                  unemployment +
                  immigration +
                  crime
                    | factor(Kommun) + factor(year) 
                    |0                       
                    |Kommun,                
                    data = DF95_sd)           


# Table for LaTeX
stargazer(ssdp_85, ssdp_90, ssdp_95,
          dep.var.labels = "SSDP vote share",
          column.labels = c("> 85 pct.", "> 90 pct.", "> 95 pct."),
          covariate.labels = c("Wildfires 2018", "Budget", "Unemployment", "Immigration",
                               "Reported crime rate"),
          add.lines = list(c("FE for municipality", "\\checkmark", "\\checkmark", "\\checkmark", "\\checkmark"),
                           c("FE for year", "\\checkmark", "\\checkmark", "\\checkmark", "\\checkmark"),
                           c("Linear trend control", "\\checkmark", "\\checkmark", "\\checkmark", "\\checkmark")),
          type = "latex", digits = 2,
          omit = c("year", "treat"),
          omit.stat = c("rsq", "adj.rsq"),
          notes = "Clustered (Municipality) standard-errors in parentheses")

#-------------------------------------------------------------------------------------------
# Test the effect of increasing damage caused by wildfires with exclusion of municipalities
# close to threshold (for appendix)
#-------------------------------------------------------------------------------------------

### The Greens

### 85th percentile
# Alter indicator
DF85_mp_excl <- D_mp %>%
  mutate(experiment = ifelse(burned_std > quantile(burned_std, 0.85, na.rm = TRUE) & year == 2018, 1, 0),
         exclusion_filter = ifelse(burned_std <= quantile(burned_std, 0.85, na.rm = TRUE) 
                                   & burned_std > quantile(burned_std, 0.75, na.rm = TRUE) 
                                   & year == 2018, 1, 0)) %>% 
  filter(!exclusion_filter == 1)

# Table E.12, column 1
greens_85_excl <- felm(vote_share ~ experiment + year:treat +
                    budget + 
                    unemployment +
                    immigration +
                    crime
                  | factor(Kommun) + factor(year)
                  |0                          
                  |Kommun,                
                  data = DF85_mp_excl)  

### 90th percentile
# Alter indicator
DF90_mp_excl <- D_mp %>%
  mutate(experiment = ifelse(burned_std > quantile(burned_std, 0.90, na.rm = TRUE) & year == 2018, 1, 0),
         exclusion_filter = ifelse(burned_std <= quantile(burned_std, 0.90, na.rm = TRUE) 
                                   & burned_std > quantile(burned_std, 0.80, na.rm = TRUE) 
                                   & year == 2018, 1, 0)) %>% 
  filter(!exclusion_filter == 1)

# Table E.12, column 2
greens_90_excl <- felm(vote_share ~ experiment + year:treat +
                         budget + 
                         unemployment +
                         immigration +
                         crime
                       | factor(Kommun) + factor(year)
                       |0                          
                       |Kommun,                
                       data = DF90_mp_excl) 

### 95th percentile
# Alter indicator
DF95_mp_excl <- D_mp %>%
  mutate(experiment = ifelse(burned_std > quantile(burned_std, 0.95, na.rm = TRUE) & year == 2018, 1, 0),
         exclusion_filter = ifelse(burned_std <= quantile(burned_std, 0.95, na.rm = TRUE) 
                                   & burned_std > quantile(burned_std, 0.85, na.rm = TRUE) 
                                   & year == 2018, 1, 0)) %>% 
  filter(!exclusion_filter == 1)

# Table E.12, column 3
greens_95_excl <- felm(vote_share ~ experiment + year:treat +
                         budget + 
                         unemployment +
                         immigration +
                         crime
                       | factor(Kommun) + factor(year)
                       |0                          
                       |Kommun,                
                       data = DF95_mp_excl)  

# Table for LaTeX
stargazer(greens_85_excl, greens_90_excl, greens_95_excl,
          dep.var.labels = "The Greens vote share",
          column.labels = c("> 85 pct.", "> 90 pct.", "> 95 pct."),
          covariate.labels = c("Wildfires 2018", "Budget", "Unemployment", "Immigration",
                               "Reported crime rate"),
          add.lines = list(c("FE for municipality", "\\checkmark", "\\checkmark", "\\checkmark", "\\checkmark"),
                           c("FE for year", "\\checkmark", "\\checkmark", "\\checkmark", "\\checkmark"),
                           c("Linear trend control", "\\checkmark", "\\checkmark", "\\checkmark", "\\checkmark")),
          type = "latex", digits = 2,
          omit = c("year", "treat"),
          omit.stat = c("rsq", "adj.rsq"),
          notes = "Clustered (Municipality) standard-errors in parentheses")

### SSDP

### 85th percentile
# Alter indicator
DF85_sd_excl <- D_sd %>%
  mutate(experiment = ifelse(burned_std > quantile(burned_std, 0.85, na.rm = TRUE) & year == 2018, 1, 0),
         exclusion_filter = ifelse(burned_std <= quantile(burned_std, 0.85, na.rm = TRUE) 
                                   & burned_std > quantile(burned_std, 0.75, na.rm = TRUE) 
                                   & year == 2018, 1, 0)) %>% 
  filter(!exclusion_filter == 1)

# Table E.13, column 1
ssdp_85_excl <- felm(vote_share ~ experiment + year:treat +
                         budget + 
                         unemployment +
                         immigration +
                         crime
                       | factor(Kommun) + factor(year)
                       |0                          
                       |Kommun,                
                       data = DF85_sd_excl)  

### 90th percentile
# Alter indicator
DF90_sd_excl <- D_sd %>%
  mutate(experiment = ifelse(burned_std > quantile(burned_std, 0.90, na.rm = TRUE) & year == 2018, 1, 0),
         exclusion_filter = ifelse(burned_std <= quantile(burned_std, 0.90, na.rm = TRUE) 
                                   & burned_std > quantile(burned_std, 0.80, na.rm = TRUE) 
                                   & year == 2018, 1, 0)) %>% 
  filter(!exclusion_filter == 1)

# Table E.13, column 2
ssdp_90_excl <- felm(vote_share ~ experiment + year:treat +
                       budget + 
                       unemployment +
                       immigration +
                       crime
                     | factor(Kommun) + factor(year)
                     |0                          
                     |Kommun,                
                     data = DF90_sd_excl) 

### 95th percentile
# Alter indicator
DF95_sd_excl <- D_sd %>%
  mutate(experiment = ifelse(burned_std > quantile(burned_std, 0.95, na.rm = TRUE) & year == 2018, 1, 0),
         exclusion_filter = ifelse(burned_std <= quantile(burned_std, 0.95, na.rm = TRUE) 
                                   & burned_std > quantile(burned_std, 0.85, na.rm = TRUE) 
                                   & year == 2018, 1, 0)) %>% 
  filter(!exclusion_filter == 1)

# Table E.13, column 3
ssdp_95_excl <- felm(vote_share ~ experiment + year:treat +
                       budget + 
                       unemployment +
                       immigration +
                       crime
                     | factor(Kommun) + factor(year)
                     |0                          
                     |Kommun,                
                     data = DF95_sd_excl)  

# Table for LaTeX
stargazer(ssdp_85_excl, ssdp_90_excl, ssdp_95_excl,
          dep.var.labels = "SSDP vote share",
          column.labels = c("> 85 pct.", "> 90 pct.", "> 95 pct."),
          covariate.labels = c("Wildfires 2018", "Budget", "Unemployment", "Immigration",
                               "Reported crime rate"),
          add.lines = list(c("FE for municipality", "\\checkmark", "\\checkmark", "\\checkmark", "\\checkmark"),
                           c("FE for year", "\\checkmark", "\\checkmark", "\\checkmark", "\\checkmark"),
                           c("Linear trend control", "\\checkmark", "\\checkmark", "\\checkmark", "\\checkmark")),
          type = "latex", digits = 2,
          omit = c("year", "treat"),
          omit.stat = c("rsq", "adj.rsq"),
          notes = "Clustered (Municipality) standard-errors in parentheses")

#-------------------------------------------------------------------------
# Models for Green Party without larger cities (For appendix)
#-------------------------------------------------------------------------

# Filter out large cities
D_mp_lcity <- D_mp %>% 
  filter(!Kommun %in% c("Stockholm", "Göteborg"))

### The Greens

# Table F.16, column 1
greens_lcity1 <- felm(vote_share ~ experiment + year:treat
                       | factor(Kommun) + factor(year)  
                       |0                            
                       |Kommun,                
                       data = D_mp_lcity)                  
summary(greens_lcity1)

# Table F.16, column 2
greens_lcity2 <- felm(vote_share ~ experiment + year:treat +
                           budget +
                           unemployment
                         | factor(Kommun) + factor(year) 
                         |0                            
                         |Kommun,                
                         data = D_mp_lcity)                   
summary(greens_lcity2)

# Table F.16, column 3
greens_lcity3 <- felm(vote_share ~ experiment + year:treat +
                           budget +
                           unemployment +
                           immigration
                         | factor(Kommun) + factor(year) 
                         |0                            
                         |Kommun,                
                         data = D_mp_lcity)                   
summary(greens_lcity3)

# Table F.16, column 4
greens_lcity4 <- felm(vote_share ~ experiment + year:treat +
                           budget + 
                           unemployment +
                           immigration +
                           crime
                         | factor(Kommun) + factor(year) 
                         |0                            
                         |Kommun,                
                         data = D_mp_lcity)                   
summary(greens_lcity4)

# Table for LaTeX
stargazer(greens_lcity1, greens_lcity2, greens_lcity3, greens_lcity4,
          dep.var.labels = "The Greens vote share",
          covariate.labels = c("Wildfires 2018", "Budget", "Unemployment", "Immigration",
                               "Reported crime rate"),
          add.lines = list(c("FE for municipality", "\\checkmark", "\\checkmark", "\\checkmark", "\\checkmark"),
                           c("FE for year", "\\checkmark", "\\checkmark", "\\checkmark", "\\checkmark"),
                           c("Linear trend control", "\\checkmark", "\\checkmark", "\\checkmark", "\\checkmark")),
          type = "latex", digits = 2,
          omit = c("year", "treat"),
          omit.stat = c("rsq", "adj.rsq"),
          notes = "Clustered (Municipality) standard-errors in parentheses")

### SSDP

# Filter out large cities of df
D_sd_lcity <- D_sd %>% 
  filter(!Kommun %in% c("Stockholm", "Göteborg"))

# Table F.17, column 1
ssdp_lcity1 <- felm(vote_share ~ experiment + year:treat 
                       | factor(Kommun) + factor(year)  
                       |0                            
                       |Kommun,                
                       data = D_sd_lcity)                   
summary(ssdp_lcity1)

# Table F.17, column 2
ssdp_lcity2 <- felm(vote_share ~ experiment + year:treat +
                           budget +
                           unemployment
                         | factor(Kommun) + factor(year) 
                         |0                            
                         |Kommun,                
                         data = D_sd_lcity)                   
summary(ssdp_lcity2)

# Table F.17, column 3
ssdp_lcity3 <- felm(vote_share ~ experiment + year:treat +
                           budget +
                           unemployment +
                           immigration
                         | factor(Kommun) + factor(year) 
                         |0                            
                         |Kommun,                
                         data = D_sd_lcity)                   
summary(ssdp_lcity3)

# Table F.17, column 4
ssdp_lcity4 <- felm(vote_share ~ experiment + year:treat +
                           budget + 
                           unemployment +
                           immigration +
                           crime
                         | factor(Kommun) + factor(year) 
                         |0                            
                         |Kommun,                
                         data = D_sd_lcity)                   
summary(ssdp_lcity4)

# Table for LaTeX
stargazer(ssdp_lcity1, ssdp_lcity2, ssdp_lcity3, ssdp_lcity4,
          dep.var.labels = "SSDP vote share",
          covariate.labels = c("Wildfires 2018", "Budget", "Unemployment", "Immigration",
                               "Reported crime rate"),
          add.lines = list(c("FE for municipality", "\\checkmark", "\\checkmark", "\\checkmark", "\\checkmark"),
                           c("FE for year", "\\checkmark", "\\checkmark", "\\checkmark", "\\checkmark"),
                           c("Linear trend control", "\\checkmark", "\\checkmark", "\\checkmark", "\\checkmark")),
          type = "latex", digits = 2,
          omit = c("year", "treat"),
          omit.stat = c("rsq", "adj.rsq"),
          notes = "Clustered (Municipality) standard-errors in parentheses")

#-------------------------------------------------------------------------------------------
# Weighting for municipality size
#-------------------------------------------------------------------------------------------

# Load total number of voters per municipality for weights
tot_votes <- readRDS("2_Cleaned_Data/tot_votes.rds")

# For the Green Party
D_mp <- readRDS("2_Cleaned_Data/D_mp.rds") %>% 
  left_join(tot_votes, by = c("Kommun", "year"))

# Table G.18, column 1
greens_weight1 <- feols(vote_share ~ experiment + year:treat 
                    | Kommun + year,                
                    data = D_mp,
                    weights = ~tot_votes,
                    cluster = "Kommun")                  
summary(greens_weight1)

# Table G.18, column 2
greens_weight2 <- feols(vote_share ~ experiment + year:treat + 
                        budget +
                        unemployment
                      | Kommun + year,                
                      data = D_mp,
                      weights = ~tot_votes,
                      cluster = "Kommun")                  
summary(greens_weight2)

# Table G.18, column 3
greens_weight3 <- feols(vote_share ~ experiment + year:treat + 
                        budget +
                        unemployment +
                        immigration
                      | Kommun + year,                
                      data = D_mp,
                      weights = ~tot_votes,
                      cluster = "Kommun")                   
summary(greens_weight3)

# Table G.18, column 4
greens_weight4 <- feols(vote_share ~ experiment + year:treat + 
                        budget +
                        unemployment +
                        immigration +
                        crime
                      | Kommun + year,                
                      data = D_mp,
                      weights = ~tot_votes,
                      cluster = "Kommun") 
summary(greens_weight4)

# Show table (output in article involved some manual typing to match the other tables created with stargazer)
# Create a list of models
model_list <- list(greens_weight1, greens_weight2, greens_weight3, greens_weight4)

# Create a table using texreg
library(texreg)
screenreg(model_list,
          stars = c(0.1, 0.05, 0.01),
          custom.model.names = c("(1)", "(2)", "(3)", "(4)"),
          custom.coef.names = c("Wildfires 2018", "Budget", "Unemployment", "Immigration", "Reported Crime Rate"),
          custom.gof.names = c("Observations"),
          custom.gof.rows = list("FE for municipality" = c("Yes", "Yes", "Yes", "Yes"),
                                 "FE for year" = c("Yes", "Yes", "Yes", "Yes"),
                                 "Linear trend control" = c("Yes", "Yes", "Yes", "Yes"),
                                 "Weights" = c("Yes", "Yes", "Yes", "Yes"),
                                 "Residual Std. Error" = paste(lapply(model_list, sigma)),
                                 "Degrees of freedom" = paste(lapply(1:length(model_list), function(x) degrees_freedom(model_list[[x]],type="resid")))),
          custom.note = "Clustered (Municipality) standard errors in parentheses. Regression weights equal number of elligible voters in each municipality.",
          digits = 4,
          omit.coef = "treat",
          include.groups = FALSE,
          include.rsq = FALSE,
          include.adjrs = FALSE,
          caption = "Fixed Effects Regression Models",
          caption.above = T,
          label = "tab:weighted_fe_models",
          booktabs = T)

#-------------------------------------------------------------------------------------------
# Spatial regression
#-------------------------------------------------------------------------------------------
### The Greens

# Join centroids to dataframe
D_mp_spat <- D_mp %>% 
  left_join(cent_kn %>% select(knnamn, knkod, ggplot_long, ggplot_lat, leaflet_long, leaflet_lat), by = c("Kommun"="knnamn")) %>% 
  mutate(knkod=as.numeric(knkod)) %>% 
  select(vote_share, experiment, budget, unemployment, immigration, crime, leaflet_lat, leaflet_long, knkod, year, post, treat) %>% 
  na.omit()

D_mp_spat <- D_mp_spat %>% 
  group_by(knkod) %>% 
  mutate(year_treat=year*treat) %>% 
  ungroup()

#specify spatial regression model
spat_mp <- conleyreg(
  
  vote_share ~ experiment + budget + unemployment + immigration + crime + year_treat + as.factor(year) + as.factor(knkod),
  D_mp_spat,
  dist_cutoff = 100,
  model = "ols",
  unit = "knkod",
  time = "year",
  lat = "leaflet_lat",
  lon = "leaflet_long",
  kernel = "bartlett",
  crs = "EPSG:3857"
) 

### SSDP
D_sd_spat <- D_sd %>% 
  left_join(cent_kn %>% select(knnamn, knkod, ggplot_long, ggplot_lat, leaflet_long, leaflet_lat), by = c("Kommun"="knnamn")) %>% 
  mutate(knkod=as.numeric(knkod)) %>% 
  select(vote_share, budget, unemployment, immigration, crime, leaflet_lat, leaflet_long, knkod, year, post, experiment, treat) %>% 
  na.omit()

D_sd_spat <- D_sd_spat %>% 
  group_by(knkod) %>% 
  mutate(year_treat=year*treat) %>% 
  ungroup()

#specify spatial regression model
spat_sd <- conleyreg(
  
  vote_share ~ experiment + budget + unemployment + immigration + crime + year_treat + as.factor(year) + as.factor(knkod),
  D_sd_spat,
  dist_cutoff = 100,
  model = "ols",
  unit = "knkod",
  time = "year",
  lat = "leaflet_lat",
  lon = "leaflet_long",
  kernel = "bartlett",
  crs = "EPSG:3857"
) 

stargazer(spat_mp, spat_sd,
          title = "Spatial regression for Green party and SSDP",
          dep.var.labels = "",
          #covariate.labels = c("Wildfires 2018", "Budget", "Unemployment", "Immigration",
           #                    "Reported crime rate"),
          column.labels = c("Green party vote share", "SSDP vote share"),
          column.separate = c(1, 2),
          type = "latex", digits = 2,
          notes.label = "",
          notes = c("Conley standard-errors using municipality centroids in parentheses", "Signif. Codes: ***: 0.01, **: 0.05, *: 0.1"),
          notes.append = F,
          omit = c("as", "year\\_treat"),
          covariate.labels = c("Wildfires 2018", "Budget", "Unemployment", "Immigration",
                               "Reported crime rate"),
          add.lines = list(c("FE for municipality", "\\checkmark", "\\checkmark"),
                           c("FE for year", "\\checkmark", "\\checkmark"),
                           c("Linear trend control", "\\checkmark", "\\checkmark")))

#-------------------------------------------------------------------------------------------
# Split sample regressions
#-------------------------------------------------------------------------------------------

### The Greens

# Read forest and total land area in 2015
forest_land_area <- read.xlsx("1_Raw_Data/Controls/forest_area_per_land.xlsx") # Land use in Sweden, hectares by every fifth year, region and land use category

# Calculate forest share and format for join
forest_land_area_15 <- forest_land_area %>% 
  mutate(Kommun = str_trim(str_remove(Kommun, "[:digit:]{4} ")),
         forest_share = total.forest.land/total.land.area) %>% 
  select(Kommun, forest_share)

# Join in forest share
D_mp <- D_mp %>% 
  left_join(forest_land_area_15, by = "Kommun")

# Retrieve median for treatment group
treat_med_forest <- median(D_mp$forest_share[which(D_mp$treat==1)])

# Run the main model, subsetting for municipality years with population density above the median
above_forest_mp <- felm(vote_share ~ experiment + year:treat +
                     budget + 
                     unemployment +
                     immigration +
                     crime
                   | factor(Kommun) + factor(year)
                   |0                            
                   |Kommun,                
                   data = D_mp %>% filter(forest_share > treat_med_forest))
summary(above_forest_mp)

# Same, subsetting below median
below_forest_mp <- felm(vote_share ~ experiment + year:treat +
                        budget + 
                        unemployment +
                        immigration +
                        crime
                      | factor(Kommun) + factor(year)
                      |0                            
                      |Kommun,                
                      data = D_mp %>% filter(forest_share < treat_med_forest))
summary(below_forest_mp)

### SSDP

# Join in forest share
D_sd <- D_sd %>% 
  left_join(forest_land_area_15, by = "Kommun") %>% 
  rename(sd_vote_share=vote_share)

#run the main model, subsetting for municipality years with population density above the median
above_forest_sd <- felm(sd_vote_share ~ experiment + year:treat +
                       budget + 
                       unemployment +
                       immigration +
                       crime
                     | factor(Kommun) + factor(year)
                     |0                            
                     |Kommun,                
                     data = D_sd %>% filter(forest_share > treat_med_forest))
summary(above_forest_sd)

# same, subsetting below median
below_forest_sd <- felm(sd_vote_share ~ experiment + year:treat +
                       budget + 
                       unemployment +
                       immigration +
                       crime
                     | factor(Kommun) + factor(year)
                     |0                            
                     |Kommun,                
                     data = D_sd %>% filter(forest_share < treat_med_forest))
summary(below_forest_sd)

# Table for LaTeX
stargazer(above_forest_mp, below_forest_mp, above_forest_sd, below_forest_sd, 
          column.labels = c("> median", "< median", "> median", "< median"),
          dep.var.labels = c("The Greens Vote share", "The SSDP vote share"),
          covariate.labels = c("Wildfires 2018", "Budget", "Unemployment", "Immigration",
                               "Reported crime rate"),
          add.lines = list(c("FE for municipality", "\\checkmark", "\\checkmark", "\\checkmark", "\\checkmark"),
                           c("FE for year", "\\checkmark", "\\checkmark", "\\checkmark", "\\checkmark"),
                           c("Linear trend control", "\\checkmark", "\\checkmark", "\\checkmark", "\\checkmark")),
          type = "latex", digits = 2,
          omit = "year",
          omit.stat = c("rsq", "adj.rsq"),
          notes = "Clustered (Municipality) standard-errors in parentheses")

#-------------------------------------------------------------------------------------------
# Effects on turnout
#-------------------------------------------------------------------------------------------

turnout <- readRDS("2_Cleaned_Data/Turnout_data.rds")

turnout <- D_mp %>% 
  left_join(turnout %>% select(turnout, Kommun, year), by=c("Kommun", "year"))

# Table J.22, column 1
turnout_m1 <- felm(turnout ~ experiment + year:treat 
              | factor(Kommun) + factor(year)  
              |0                            
              |Kommun,                
              data = turnout)                   
summary(turnout_m1)

# Table J.22, column 2
turnout_m2 <- felm(turnout ~ experiment + year:treat +
                  budget +
                  unemployment
                | factor(Kommun) + factor(year) 
                |0                            
                |Kommun,                
                data = turnout)                   
summary(turnout_m2)

# Table J.22, column 3
turnout_m3 <- felm(turnout ~ experiment + year:treat +
                  budget +
                  unemployment +
                  immigration
                | factor(Kommun) + factor(year) 
                |0                            
                |Kommun,                
                data = turnout)                   
summary(turnout_m3)

# Table J.22, column 4
turnout_m4 <- felm(turnout ~ experiment + year:treat +
                  budget + 
                  unemployment +
                  immigration +
                  crime
                | factor(Kommun) + factor(year) 
                |0                            
                |Kommun,                
                data = turnout)                   
summary(turnout_m4)

# Table for LaTeX
stargazer(turnout_m1, turnout_m2, turnout_m3, turnout_m4,
          dep.var.labels = "Turnout",
          covariate.labels = c("Wildfires 2018", "Budget", "Unemployment", "Immigration",
                               "Reported crime rate"),
          add.lines = list(c("FE for municipality", "\\checkmark", "\\checkmark", "\\checkmark", "\\checkmark"),
                           c("FE for year", "\\checkmark", "\\checkmark", "\\checkmark", "\\checkmark"),
                           c("Linear trend control", "\\checkmark", "\\checkmark", "\\checkmark", "\\checkmark")),
          type = "latex", digits = 2,
          omit = c("year", "treat"),
          omit.stat = c("rsq", "adj.rsq"),
          notes = "Clustered (Municipality) standard-errors in parentheses")
